/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/
#ifndef SFX2_SFXCOMMANDS_HRC
#define SFX2_SFXCOMMANDS_HRC

#define CMD_SID_VIEWSHELL0                          ".uno:_SwitchViewShell0"
#define CMD_SID_VIEWSHELL1                          ".uno:_SwitchViewShell1"
#define CMD_SID_VIEWSHELL2                          ".uno:_SwitchViewShell2"
#define CMD_SID_VIEWSHELL3                          ".uno:_SwitchViewShell3"
#define CMD_SID_VIEWSHELL4                          ".uno:_SwitchViewShell4"
#define CMD_SID_ABOUT                               ".uno:About"
#define CMD_SID_ACTIVATE                            ".uno:Activate"
#define CMD_SID_HELPBALLOONS                        ".uno:ActiveHelp"
#define CMD_SID_STYLE_FAMILY                        ".uno:ActualStyleFamily"
#define CMD_SID_NEWDOC                              ".uno:NewDoc"
#define CMD_SID_CREATELINK                          ".uno:AddBookmark"
#define CMD_SID_NEWDOCDIRECT                        ".uno:AddDirect"
#define CMD_SID_TEMPLATE_ADDRESSBOKSOURCE           ".uno:AddressBookSource"
#define CMD_SID_BASICIDE_ADDWATCH                   ".uno:AddWatch"
#define CMD_SID_DOCINFO_AUTHOR                      ".uno:Author"
#define CMD_SID_AUTOHIDE                            ".uno:AutoHide"
#define CMD_SID_AUTOPILOTMENU                       ".uno:AutoPilotMenu"
#define CMD_SID_GALLERY_BG_BRUSH                    ".uno:BackgroundImage"
#define CMD_SID_BACKSPACE                           ".uno:Backspace"
#define CMD_SID_BASICBREAK                          ".uno:BasicBreak"
#define CMD_SID_BASICIDE_APPEAR                     ".uno:BasicIDEAppear"
#define CMD_SID_BASICSTEPINTO                       ".uno:BasicStepInto"
#define CMD_SID_BASICSTEPOUT                        ".uno:BasicStepOut"
#define CMD_SID_BASICSTEPOVER                       ".uno:BasicStepOver"
#define CMD_SID_BASICSTOP                           ".uno:BasicStop"
#define CMD_SID_BROWSER                             ".uno:Beamer"
#define CMD_SID_BASICIDE_BRKPNTSCHANGED             ".uno:BreakPointsChanged"
#define CMD_SID_BROWSE_BACKWARD                     ".uno:BrowseBackward"
#define CMD_SID_BROWSE_FORWARD                      ".uno:BrowseForward"
#define CMD_SID_BROWSER_MODE                        ".uno:BrowseView"
#define CMD_SID_BUILD_VERSION                       ".uno:BuildVersion"
#define CMD_SID_CAPTION                             ".uno:Caption"
#define CMD_SID_STYLE_FAMILY1                       ".uno:CharStyle"
#define CMD_SID_CHECK_KEY                           ".uno:CheckKey"
#define CMD_SID_BASICIDE_CHOOSEMACRO                ".uno:ChooseMacro"
#define CMD_SID_CLEARHISTORY                        ".uno:ClearHistory"
#define CMD_SID_CLOSEWINS                           ".uno:CloseWins"
#define CMD_SID_CLOSEDOCS                           ".uno:CloseDocs"
#define CMD_SID_CLOSEDOC                            ".uno:CloseDoc"
#define CMD_SID_CLOSEWIN                            ".uno:CloseWin"
#define CMD_SID_CLOSING                             ".uno:Closing"
#define CMD_SID_DOCINFO_COMMENTS                    ".uno:Comments"
#define CMD_SID_OFFICE_COMMERCIAL_USE               ".uno:CommercialUse"
#define CMD_SID_DOCUMENT_COMPARE                    ".uno:CompareDocuments"
#define CMD_SID_BASICCOMPILE                        ".uno:CompileBasic"
#define CMD_SID_CONFIG                              ".uno:ConfigureDialog"
#define CMD_SID_CONTEXT                             ".uno:Context"
#define CMD_SID_COPY                                ".uno:Copy"
#define CMD_SID_CRASH                               ".uno:Crash"
#define CMD_SID_BASICIDE_CREATEMACRO                ".uno:CreateMacro"
#define CMD_SID_CURRENT_URL                         ".uno:CurrentURL"
#define CMD_SID_CURSORENDOFSCREEN                   ".uno:CursorEndOfScreen"
#define CMD_SID_CURSORTOPOFSCREEN                   ".uno:CursorTopOfScreen"
#define CMD_SID_OFFICE_CUSTOMERNUMBER               ".uno:CustomerNumber"
#define CMD_SID_CUT                                 ".uno:Cut"
#define CMD_SID_DEFAULTFILEPATH                     ".uno:DefaultFilePath"
#define CMD_SID_DEFAULTFILENAME                     ".uno:DefaultFileName"
#define CMD_SID_DELETE                              ".uno:Delete"
#define CMD_SID_BASICIDE_DELETECURRENT              ".uno:DeleteCurrent"
#define CMD_SID_STYLE_DELETE                        ".uno:DeleteStyle"
#define CMD_SID_STYLE_DESIGNER                      ".uno:DesignerDialog"
#define CMD_SID_STYLE_DRAGHIERARCHIE                ".uno:DragHierarchy"
#define CMD_SID_EDITDOC                             ".uno:EditDoc"
#define CMD_SID_BASICIDE_EDITMACRO                  ".uno:EditMacro"
#define CMD_SID_STYLE_EDIT                          ".uno:EditStyle"
#define CMD_FID_SEARCH_NOW                          ".uno:ExecuteSearch"
#define CMD_SID_EXTENDEDHELP                        ".uno:ExtendedHelp"
#define CMD_SID_FILE_NAME                           ".uno:FileName"
#define CMD_SID_FOCUSURLBOX                         ".uno:FocusUrlBox"
#define CMD_SID_FORMATMENU                          ".uno:FormatMenu"
#define CMD_SID_STYLE_FAMILY3                       ".uno:FrameStyle"
#define CMD_SID_PROGFILENAME                        ".uno:FullName"
#define CMD_SID_DOCFULLNAME                         ".uno:FullName"
#define CMD_SID_WIN_FULLSCREEN                      ".uno:FullScreen"
#define CMD_SID_FILLFRAME                           ".uno:GetFrameWindow"
#define CMD_SID_CURSORDOWN                          ".uno:GoDown"
#define CMD_SID_CURSORPAGEDOWN                      ".uno:GoDownBlock"
#define CMD_SID_CURSORPAGEDOWN_SEL                  ".uno:GoDownBlockSel"
#define CMD_SID_CURSORDOWN_SEL                      ".uno:GoDownSel"
#define CMD_SID_CURSORLEFT                          ".uno:GoLeft"
#define CMD_SID_CURSORPAGELEFT                      ".uno:GoLeftBlock"
#define CMD_SID_CURSORPAGELEFT_SEL                  ".uno:GoLeftBlockSel"
#define CMD_SID_CURSORLEFT_SEL                      ".uno:GoLeftSel"
#define CMD_SID_CURSORRIGHT                         ".uno:GoRight"
#define CMD_SID_CURSORRIGHT_SEL                     ".uno:GoRightSel"
#define CMD_SID_CURSORENDOFFILE                     ".uno:GoToEndOfData"
#define CMD_SID_CURSORENDOFFILE_SEL                 ".uno:GoToEndOfDataSel"
#define CMD_SID_CURSOREND                           ".uno:GoToEndOfRow"
#define CMD_SID_CURSOREND_SEL                       ".uno:GoToEndOfRowSel"
#define CMD_SID_CURSORTOPOFFILE                     ".uno:GoToStart"
#define CMD_SID_CURSORHOME                          ".uno:GoToStartOfRow"
#define CMD_SID_CURSORHOME_SEL                      ".uno:GoToStartOfRowSel"
#define CMD_SID_CURSORTOPOFFILE_SEL                 ".uno:GoToStartSel"
#define CMD_SID_CURSORUP                            ".uno:GoUp"
#define CMD_SID_CURSORPAGEUP                        ".uno:GoUpBlock"
#define CMD_SID_CURSORPAGEUP_SEL                    ".uno:GoUpBlockSel"
#define CMD_SID_CURSORUP_SEL                        ".uno:GoUpSel"
#define CMD_SID_HELP_ANNOTATE                       ".uno:HelpAnnotate"
#define CMD_SID_HELP_BOOKMARK                       ".uno:HelpBookmark"
#define CMD_SID_HELP_HELPFILEBOX                    ".uno:HelpChooseFile"
#define CMD_SID_HELP_DOWNLOAD                       ".uno:HelpDownload"
#define CMD_SID_HELP_PI                             ".uno:HelperDialog"
#define CMD_SID_HELPINDEX                           ".uno:HelpIndex"
#define CMD_SID_HELPMENU                            ".uno:HelpMenu"
#define CMD_SID_HELPONHELP                          ".uno:HelpOnHelp"
#define CMD_SID_HELP_SEARCH                         ".uno:HelpSearch"
#define CMD_SID_HELPTIPS                            ".uno:HelpTip"
#define CMD_SID_HELP_ZOOMIN                         ".uno:HelpZoomIn"
#define CMD_SID_HELP_ZOOMOUT                        ".uno:HelpZoomOut"
#define CMD_SID_BASICIDE_HIDECURPAGE                ".uno:HideCurPage"
#define CMD_SID_HYPERLINK_DIALOG                    ".uno:HyperlinkDialog"
#define CMD_SID_INSERTDOC                           ".uno:InsertDoc"
#define CMD_SID_HYPERLINK_INSERT                    ".uno:InsertHyperlink"
#define CMD_SID_INSERT_FLOATINGFRAME                ".uno:InsertObjectFloatingFrame"
#define CMD_SID_INTERNET_ONLINE                     ".uno:InternetOnline"
#define CMD_SID_INTERNET_SEARCH                     ".uno:InternetSearch"
#define CMD_SID_DOC_LOADING                         ".uno:IsLoading"
#define CMD_SID_IMG_LOADING                         ".uno:IsLoadingImages"
#define CMD_SID_PRINTOUT                            ".uno:IsPrinting"
#define CMD_SID_JUMPTOMARK                          ".uno:JumpToMark"
#define CMD_SID_DOCINFO_KEYWORDS                    ".uno:Keywords"
#define CMD_SID_BASICIDE_LIBLOADED                  ".uno:LibLoaded"
#define CMD_SID_BASICIDE_LIBREMOVED                 ".uno:LibRemoved"
#define CMD_SID_BASICIDE_LIBSELECTED                ".uno:LibSelect"
#define CMD_SID_BASICIDE_LIBSELECTOR                ".uno:LibSelector"
#define CMD_SID_OFFICE_PLK                          ".uno:LicenceKey"
#define CMD_SID_CONFIGACCEL                         ".uno:LoadAccel"
#define CMD_SID_BASICLOAD                           ".uno:LoadBasic"
#define CMD_SID_LOADCONFIG                          ".uno:LoadConfiguration"
#define CMD_SID_CONFIGEVENT                         ".uno:LoadEvents"
#define CMD_SID_CONFIGMENU                          ".uno:LoadMenu"
#define CMD_SID_CONFIGSTATUSBAR                     ".uno:LoadStatusBar"
#define CMD_SID_TOOLBOXOPTIONS                      ".uno:LoadToolBox"
#define CMD_SID_LOGOUT                              ".uno:Logout"
#define CMD_SID_SCRIPTORGANIZER                     ".uno:ScriptOrganizer"
#define CMD_SID_MACROORGANIZER                      ".uno:MacroOrganizer"
#define CMD_SID_RUNMACRO                            ".uno:RunMacro"
#define CMD_SID_BASICCHOOSER                        ".uno:MacroDialog"
#define CMD_SID_MAIL_NOTIFY                         ".uno:MailReceipt"
#define CMD_SID_MAIL_CHILDWIN                       ".uno:MailWindow"
#define CMD_SID_BASICIDE_MATCHGROUP                 ".uno:MatchGroup"
#define CMD_SID_TOGGLE_MENUBAR                      ".uno:MenuBarVisible"
#define CMD_SID_DOCUMENT_MERGE                      ".uno:MergeDocuments"
#define CMD_SID_ATTR_METRIC                         ".uno:MetricUnit"
#define CMD_SID_MODIFIED                            ".uno:Modified"
#define CMD_SID_DOC_MODIFIED                        ".uno:ModifiedStatus"
#define CMD_SID_BASICIDE_MODULEDLG                  ".uno:ModuleDialog"
#define CMD_SID_BASICIDE_NAMECHANGEDONTAB           ".uno:NameChangedOnTab"
#define CMD_SID_NAVIGATOR                           ".uno:Navigator"
#define CMD_SID_RESTORE_EDITING_VIEW                ".uno:RestoreEditingView"
#define CMD_SID_BASICIDE_NEWDIALOG                  ".uno:NewDialog"
#define CMD_SID_BASICIDE_NEWMODULE                  ".uno:NewModule"
#define CMD_SID_CREATE_BASICOBJECT                  ".uno:NewObject"
#define CMD_SID_STYLE_NEW                           ".uno:NewStyle"
#define CMD_SID_NEWWINDOW                           ".uno:NewWindow"
#define CMD_SID_BASICIDE_OBJCAT                     ".uno:ObjectCatalog"
#define CMD_SID_OBJECT                              ".uno:ObjectMenue"
#define CMD_SID_OLD_PALK                            ".uno:OldPALK"
#define CMD_SID_OPENDOC                             ".uno:Open"
#define CMD_SID_WEBHTML                             ".uno:WebHtml"
#define CMD_SID_OPENHYPERLINK                       ".uno:OpenHyperlink"
#define CMD_SID_DOCINFO_TITLE                       ".uno:DocInfoTitle"
#define CMD_SID_OPENTEMPLATE                        ".uno:OpenTemplate"
#define CMD_SID_OPENURL                             ".uno:OpenUrl"
#define CMD_SID_OPTIONS                             ".uno:Options"
#define CMD_SID_ORGANIZER                           ".uno:Organizer"
#define CMD_SID_STYLE_FAMILY4                       ".uno:PageStyle"
#define CMD_SID_STYLE_FAMILY2                       ".uno:ParaStyle"
#define CMD_SID_PARTWIN                             ".uno:PartWindow"
#define CMD_SID_PASTE                               ".uno:Paste"
#define CMD_SID_CLIPBOARD_FORMAT_ITEMS              ".uno:ClipboardFormatItems"
#define CMD_SID_PASTE_SPECIAL                       ".uno:PasteSpecial"
#define CMD_SID_PASTE_ONLY                          ".uno:PasteOnly"
#define CMD_SID_PASTE_ONLY_VALUE                    ".uno:PasteOnlyValue"
#define CMD_SID_PASTE_ONLY_TEXT                     ".uno:PasteOnlyText"
#define CMD_SID_PASTE_ONLY_FORMULA                  ".uno:PasteOnlyFormula"
#define CMD_SID_DOCPATH                             ".uno:DocPath"
#define CMD_SID_PICKLIST                            ".uno:PickList"
#define CMD_SID_PLUGINS_ACTIVE                      ".uno:PlugInsActive"
#define CMD_SID_PRINTDOC                            ".uno:Print"
#define CMD_SID_PRINTDOCDIRECT                      ".uno:PrintDefault"
#define CMD_SID_PRINTER_NAME                        ".uno:Printer"
#define CMD_SID_SETUPPRINTER                        ".uno:PrinterSetup"
#define CMD_SID_PRINTPREVIEW                        ".uno:PrintPreview"
#define CMD_SID_OFFICE_PRIVATE_USE                  ".uno:PrivateUse"
#define CMD_SID_DOCINFO                             ".uno:SetDocumentProperties"
#define CMD_SID_QUITAPP                             ".uno:Quit"
#define CMD_SID_DOC_READONLY                        ".uno:ReadOnly"
#define CMD_SID_RECORDMACRO                         ".uno:MacroRecorder"
#define CMD_SID_STOP_RECORDING                      ".uno:StopRecording"
#define CMD_SID_RECORDING_FLOATWINDOW               ".uno:MacroRecordingFloat"
#define CMD_SID_REDO                                ".uno:Redo"
#define CMD_SID_DELETE_BASICOBJECT                  ".uno:ReleaseObject"
#define CMD_SID_RELOAD                              ".uno:Reload"
#define CMD_SID_BASICIDE_REMOVEWATCH                ".uno:RemoveWatch"
#define CMD_SID_BASICIDE_RENAMECURRENT              ".uno:RenameCurrent"
#define CMD_SID_REPAINT                             ".uno:Repaint"
#define CMD_SID_REPEAT                              ".uno:RepeatAction"
#define CMD_SID_RUBY_DIALOG                         ".uno:RubyDialog"
#define CMD_SID_BASICRUN                            ".uno:RunBasic"
#define CMD_SID_SAVEDOC                             ".uno:Save"
#define CMD_SID_SAVEDOCS                            ".uno:SaveAll"
#define CMD_SID_SAVEASDOC                           ".uno:SaveAs"
#define CMD_SID_DOCTEMPLATE                         ".uno:SaveAsTemplate"
#define CMD_SID_BASICSAVEAS                         ".uno:SaveBasicAs"
#define CMD_SID_EXPORT_DIALOG                       ".uno:ExportDialog"
#define CMD_SID_IMPORT_DIALOG                       ".uno:ImportDialog"
#define CMD_SID_SAVECONFIG                          ".uno:SaveConfiguration"
#define CMD_SID_DOC_SAVED                           ".uno:Saved"
#define CMD_SID_BASICIDE_SBXDELETED                 ".uno:SbxDeleted"
#define CMD_SID_BASICIDE_SBXINSERTED                ".uno:SbxInserted"
#define CMD_SID_BASICIDE_SBXRENAMED                 ".uno:SbxRenamed"
#define CMD_SID_MAIL_SCROLLBODY_PAGEDOWN            ".uno:ScrollBodyPageDown"
#define CMD_SID_SEARCH_DLG                          ".uno:SearchDialog"
#define CMD_SID_SEARCH_OPTIONS                      ".uno:SearchOptions"
#define CMD_SID_SEARCH_ITEM                         ".uno:SearchProperties"
#define CMD_SID_SELECTALL                           ".uno:SelectAll"
#define CMD_FN_FAX                                  ".uno:SendFax"
#define CMD_SID_MAIL_SENDDOC                        ".uno:SendMail"
#define CMD_SID_MAIL_SENDDOCASPDF                   ".uno:SendMailDocAsPDF"
#define CMD_SID_MAIL_SENDDOCASFORMAT                ".uno:SendMailDocAsFormat"
#define CMD_SID_MAIL_SENDDOCASMS                    ".uno:SendMailDocAsMS"
#define CMD_SID_MAIL_SENDDOCASOOO                   ".uno:SendMailDocAsOOo"
#define CMD_SID_SETOPTIONS                          ".uno:SetOptions"
#define CMD_SID_OFFICE_PALK                         ".uno:SetPALK"
#define CMD_SID_SHOW_BROWSER                        ".uno:ShowBrowser"
#define CMD_SID_SHOWPOPUPS                          ".uno:ShowPopups"
#define CMD_SID_BASICIDE_SHOWSBX                    ".uno:ShowSbx"
#define CMD_SID_SOURCEVIEW                          ".uno:SourceView"
#define CMD_SID_STATUSBARTEXT                       ".uno:StatusBar"
#define CMD_SID_TOGGLESTATUSBAR                     ".uno:StatusBarVisible"
#define CMD_SID_BASICIDE_STAT_DATE                  ".uno:StatusGetDate"
#define CMD_SID_BASICIDE_STAT_POS                   ".uno:StatusGetPosition"
#define CMD_SID_BASICIDE_STAT_TITLE                 ".uno:StatusGetTitle"
#define CMD_SID_BASICIDE_STOREALLMODULESOURCES      ".uno:StoreAllModuleSources"
#define CMD_SID_BASICIDE_STOREMODULESOURCE          ".uno:StoreModuleSource"
#define CMD_SID_STYLE_APPLY                         ".uno:StyleApplyState"
#define CMD_SID_STYLE_CATALOG                       ".uno:StyleCatalog"
#define CMD_SID_STYLE_NEW_BY_EXAMPLE                ".uno:StyleNewByExample"
#define CMD_SID_STYLE_UPDATE_BY_EXAMPLE             ".uno:StyleUpdateByExample"
#define CMD_SID_STYLE_WATERCAN                      ".uno:StyleWatercanMode"
#define CMD_SID_VIEWSHELL                           ".uno:SwitchViewShell"
#define CMD_SID_TASKBAR                             ".uno:TaskBarVisible"
#define CMD_SID_STYLE_FAMILY5                       ".uno:ListStyle"
#define CMD_SID_TIPWINDOW                           ".uno:TipsDialog"
#define CMD_SID_DOCTITLE                            ".uno:Title"
#define CMD_SID_TITLE                               ".uno:Title"
#define CMD_SID_BASICIDE_TOGGLEBRKPNT               ".uno:ToggleBreakPoint"
#define CMD_SID_BASICIDE_SHOWWINDOW                 ".uno:BasicIDEShowWindow"
#define CMD_SID_UNDO                                ".uno:Undo"
#define CMD_SID_FORMATPAINTBRUSH                    ".uno:FormatPaintbrush"
#define CMD_SID_ATTR_UNDO_COUNT                     ".uno:UndoCount"
#define CMD_SID_BASICIDE_UPDATEALLMODULESOURCES     ".uno:UpdateAllModuleSources"
#define CMD_SID_BASICIDE_UPDATEMODULESOURCE         ".uno:UpdateModuleSource"
#define CMD_SID_BASICIDE_MANAGEBRKPNTS              ".uno:ManageBreakPoints"
#define CMD_SID_BASICIDE_TOGGLEBRKPNTENABLED        ".uno:ToggleBreakPointEnabled"
#define CMD_SID_UPDATE_VERSION                      ".uno:UpdateVersion"
#define CMD_SID_VERSION                             ".uno:VersionDialog"
#define CMD_SID_SIGNATURE                           ".uno:Signature"
#define CMD_SID_MACRO_SIGNATURE                     ".uno:MacroSignature"
#define CMD_SID_VERSION_VISIBLE                     ".uno:VersionVisible"
#define CMD_SID_VIEW_DATA_SOURCE_BROWSER            ".uno:ViewDataSourceBrowser"
#define CMD_SID_WIN_VISIBLE                         ".uno:WinVisible"
#define CMD_SID_MDIWINDOWLIST                       ".uno:WindowList"
#define CMD_SID_ZOOM_IN                             ".uno:ZoomMinus"
#define CMD_SID_ZOOM                                ".uno:Zooming"
#define CMD_SID_ZOOM_NEXT                           ".uno:ZoomNext"
#define CMD_SID_ZOOM_OUT                            ".uno:ZoomPlus"
#define CMD_SID_ZOOM_PREV                           ".uno:ZoomPrevious"
#define CMD_SID_ZOOM_TOOLBOX                        ".uno:ZoomToolBox"
#define CMD_SID_EXPORTDOC                           ".uno:ExportTo"
#define CMD_SID_EXPORTDOCASPDF                      ".uno:ExportToPDF"
#define CMD_SID_DIRECTEXPORTDOCASPDF                ".uno:ExportDirectToPDF"
#define CMD_SID_IMAGE_ORIENTATION                   ".uno:ImageOrientation"
#define CMD_SID_SAVE_VERSION_ON_CLOSE               ".uno:SaveVersionOnClose"
#define CMD_SID_ADDONS                              ".uno:Addons"
#define CMD_SID_SHOW_IME_STATUS_WINDOW              ".uno:ShowImeStatusWindow"
#define CMD_SID_UPDATE_CONFIG                       ".uno:UpdateConfiguration"
#define CMD_SID_HELP_TUTORIALS                      ".uno:HelpTutorials"
#define CMD_SID_ADDONHELP                           ".uno:AddonHelp"
#define CMD_SID_FORMATMENUSTATE                     ".uno:FormatMenuState"
#define CMD_SID_INET_DLG                            ".uno:InternetDialog"
#define CMD_SID_OFFICE_CHECK_PLZ                    ".uno:CheckPLZ"
#define CMD_SID_ADDRESS_DATA_SOURCE                 ".uno:AutoPilotAddressDataSource"
#define CMD_FN_BUSINESS_CARD                        ".uno:InsertBusinessCard"
#define CMD_FN_LABEL                                ".uno:InsertLabels"
#define CMD_FN_XFORMS_INIT                          ".uno:NewXForms"
#define CMD_SID_SD_AUTOPILOT                        ".uno:AutoPilotPresentations"
#define CMD_SID_NEWSD                               ".uno:NewPresentation"
#define CMD_SID_COMP_BIBLIOGRAPHY                   ".uno:BibliographyComponent"
#define CMD_SID_MINIMIZED                           ".uno:Minimized"
#define CMD_SID_AUTO_CORRECT_DLG                    ".uno:AutoCorrectDlg"
#define CMD_SID_OPTIONS_TREEDIALOG                  ".uno:OptionsTreeDialog"
#define CMD_SID_TERMINATE_INPLACEACTIVATION         ".uno:TerminateInplaceActivation"
#define CMD_SID_RECENTFILELIST                      ".uno:RecentFileList"
#define CMD_SID_AVAILABLE_TOOLBARS                  ".uno:AvailableToolbars"
#define CMD_SID_AVMEDIA_PLAYER                      ".uno:AVMediaPlayer"
#define CMD_SID_INSERT_AVMEDIA                      ".uno:InsertAVMedia"
#define CMD_SID_MORE_DICTIONARIES                   ".uno:MoreDictionaries"
#define CMD_SID_ACTIVATE_STYLE_APPLY                ".uno:ActivateStyleApply"
#define CMD_SID_DOCKWIN_0                           ".uno:DockingWindow0"
#define CMD_SID_DOCKWIN_1                           ".uno:DockingWindow1"
#define CMD_SID_DOCKWIN_2                           ".uno:DockingWindow2"
#define CMD_SID_DOCKWIN_3                           ".uno:DockingWindow3"
#define CMD_SID_DOCKWIN_4                           ".uno:DockingWindow4"
#define CMD_SID_DOCKWIN_5                           ".uno:DockingWindow5"
#define CMD_SID_DOCKWIN_6                           ".uno:DockingWindow6"
#define CMD_SID_DOCKWIN_7                           ".uno:DockingWindow7"
#define CMD_SID_DOCKWIN_8                           ".uno:DockingWindow8"
#define CMD_SID_DOCKWIN_9                           ".uno:DockingWindow9"
#define CMD_SID_PASTE_UNFORMATTED                   ".uno:PasteUnformatted"

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
